
// AddrViewer.java
// Andrew Davison, November 2010, ad@fivedots.coe.psu.ac.th

/*  List the machine's IP address and all its NICs that have
    MAC addresses.

    A more fancy lister of machine network details, coded by
     Jay R. in January 2009, can be found at:
     http://stackoverflow.com/questions/494465/
       how-to-enumerate-ip-addresses-of-all-enabled-nic-cards-from-java
*/


import java.io.*;
import java.util.*;
import java.net.*;

public class AddrViewer
{
  public final static void main(String[] args)
  {
    showIP();
    showMacNICs();
  }  // end of main()


  private static void showIP()
  // print the machine's IP address
  {
    try {
      InetAddress localHost = InetAddress.getLocalHost();
      System.out.println("LocalHost IP address: " + 
                        localHost.getCanonicalHostName() + "\n");
    }
    catch (UnknownHostException e)
    {  System.out.println(" No LocalHost Info found\n"); }
      
  }  // end of showIP()



  private static void showMacNICs()
  // list the NICs that have MAC addresses
  {
    try {
      Enumeration<NetworkInterface> intfs =
                       NetworkInterface.getNetworkInterfaces();
      while(intfs.hasMoreElements()) {
        NetworkInterface intf = intfs.nextElement();
        byte[] macAddr = intf.getHardwareAddress();
        if (macAddr != null) {
          System.out.println(intf.getDisplayName());
          System.out.println("  MAC:  " + macToString(macAddr));
          System.out.println("  Operational? " + intf.isUp());
          System.out.println();
        }
      }
    }
    catch (SocketException e)
    {  e.printStackTrace(); }
  }  // end of showMacNICs()



  private static String macToString(byte[] addr) 
  /* convert a MAC address in byte form to a string 
     (using ":" as a separator)  */
  { 
    if (addr == null)
      return null; 

    int len = addr.length;
    if (len == 0)
      return null;

    StringBuilder sb = new StringBuilder();
    for (int i = 0; i < len; i++) {
      sb.append(String.format("%1$02X", addr[i]));   // 2-digit uppercase hex
      if (i != len-1)
        sb.append(":");
    }
    return sb.toString();
  }  // end of macToString()


}  // end of AddrViewer class
