
// DetectIP.java
// Andrew Davison, November 2010, ad@fivedots.coe.psu.ac.th

/* Detect the 'outward facing' IP for this machine by
   contacting the DynDNS website 
   (see details at http://www.dyndns.com/developers/checkip.html)
*/


import java.io.*;
import java.net.*;

public class DetectIP 
{

  private static final String SITE_ADDR = "http://checkip.dyndns.org/";


  public static void main (String[] args) 
  {
    String respStr = getResponse();
    if (respStr == null)
      System.out.println("No address found");
    else 
      System.out.println("Detected IP address: " + extractData(respStr));
  }  // end of main()



  private static String getResponse() 
  // access the URL, returning the response as a string
  {
    try {
      URL url = new URL(SITE_ADDR);

      URLConnection conn = url.openConnection();
      BufferedReader rd = new BufferedReader(
                        new InputStreamReader(conn.getInputStream()));

      boolean usefulInfo = false;
      StringBuilder resStr = new StringBuilder();
      String line;
      while ((line = rd.readLine()) != null) {
        //System.out.println(line);
        resStr.append(line.trim() + "\n");
      }
      return resStr.toString();
    } 
    catch (MalformedURLException e) 
    {  System.out.println("URL not understood"); } 
    catch (IOException e) 
    { System.out.println("I/O Error");  }

    return null;
   }  // end of getResponse()



  private static String extractData(String respStr)
  /* The response will have the form:
        <html><head><title>Current IP Check</title></head>
        <body>Current IP Address: 118.173.169.151</body></html>
    Extract the IP address:
        118.173.169.151
  */
  {
    // http://www.rgagnon.com/javadetails/java-0424.html
    String resStr = respStr.replaceAll("\\<.*?>","");  // remove tags

    int startPosn = resStr.indexOf(':');
    if (startPosn == -1)
      return resStr;
    else
      return resStr.substring(startPosn+2).trim();
  }  // end of extractData()


} // end of DetectIP class
