
// ListWiFis.java
// Andrew Davison, ad@fivedots.coe.psu.ac.th, November 2010

/* Use a Place Lab WiFiSpotter to gather information on WiFi
   Access Points (APs) within range of this device. The info
   includes their SSID, Mac address, and RSS.

   The Place Lab library is for device positioning (http://www.placelab.org/).
   This code is based on WiFiSpotterExample.jar in Place Lab examples.

   I'm using a cut down version of the PlaceLab.jar that only contains
   the WiFi related classes.

   For this code to work, you must first
   install the PlaceLab NDIS network protocol driver
   (ndisplab.inf and ndisplab.sys) from the Place Lab native\ 
   directory, and start it with:
      net start ndisplab
    See readme.txt in the native\ directory.

  Usage:
     > javac -cp "miniPlacelab.jar;." ListWiFis.java
     > java -cp "miniPlacelab.jar;." ListWiFis
*/

import org.placelab.core.*;
import org.placelab.spotter.*;


public class ListWiFis
{
  public static void main(String[] args) 
  {
    Spotter spotter = new WiFiSpotter();
    try {
      spotter.open();
      BeaconMeasurement bm = (BeaconMeasurement) spotter.getMeasurement();
      int numAPs = bm.numberOfReadings();
      System.out.println("No. of WiFi Access Points detected: " + numAPs + "\n");
      if (numAPs > 0) {
        WiFiReading wr;  // iterate through the readings
        for (int i=0; i < numAPs; i++) {
          wr = (WiFiReading) bm.getReading(i);
          String macAddr = wr.getId().toUpperCase();  
                    // use uppercase hex
          System.out.println(wr.getSsid() + ". MAC: " +  macAddr + 
                                  " ; RSS: " + wr.getRssi() + "\n");
        }
      }
    } 
    catch (SpotterException e) 
    {  e.printStackTrace();  }
  }  // end of main()

}  // end of ListWiFis class
