
// FindWiFiMACs.java
// Andrew Davison, November 2010, ad@fivedots.coe.psu.ac.th

/* Call the applyWNV.bat script with a file name. It calls
   WirelsssNetView.exe (http://www.nirsoft.net/utils/wireless_network_view.html)
   to store details about WiFi access points (APs) in range of this device.

   The details are read in from the file and their MAC addresses and 
   received signal strengths (RSS) are printed out.
*/

import java.io.*;
import java.net.*;


public class FindWiFiMACs 
{
  private static final String INFO_FNM = "wifiInfo.txt";


  public static void main (String[] args) 
  {
    SaferExec se = new SaferExec();          // or include a wait time in secs
    se.exec("cmd /c applyWNV " + INFO_FNM);   // cmd /c necessary for batch file

    try {
      System.out.println("Reading " + INFO_FNM + " ...");
      System.out.println();
      BufferedReader in = new BufferedReader(new FileReader(INFO_FNM));
      String wifiLine;
      while ((wifiLine = in.readLine()) != null) {
        // System.out.println(wifiLine);
        extractMACDetails(wifiLine);
      }
      in.close();
    } 
    catch (IOException e) 
    { System.out.println("Problem reading " + INFO_FNM);  }
   }  // end of main


  private static void extractMACDetails(String wifiLine)
  /* line format:
        SpeedTouch577EC9,60%,60%,1,Yes,Yes,WPA-PSK,TKIP,ERP,
           11/9/2010 5:20:03 PM,11/9/2010 5:20:03 PM,
            00-90-d0-f5-29-d2,70,2.412,1,,54 Mbps
            ^^^^^^^^^^^^^^^^^^^^
  */
  {
    String[] args = wifiLine.split(",");
    // System.out.println("No of arguments found: " + args.length);
    if (args.length != 17)
      System.out.println("Incorrect number of arguments");
    else {
      String macAddr = args[11].toUpperCase().replaceAll("-", ":");  
                    // use uppercase hex and a ":" as separator
      System.out.println(args[0] + ". MAC: " +  macAddr + 
                                  " ; RSS: " + args[12] + "\n");
    }
  }  // end of extractMACDetails()

} // end of FindWiFiMACs class
